@@ -8,6 +8,7 @@ Tests non-querying pycraigslist attributes, instance, and class methods.
 from pytest import mark
 
 import specs
+import pycraigslist
 
 
 @mark.parametrize("parent", specs.obj.pycraigslist_parents)
@@ -25,6 +26,17 @@ def test_dtype_get_categories(parent):
     assert isinstance(parent.get_categories(), dict)
 
 
+@mark.parametrize("parent", specs.obj.pycraigslist_parents)
+def test_valid_sub_classes_from_categories(parent):
+    """Tests every subclass method suggested in `get_categories()` is a valid object."""
+    parent_class_str = str(parent).split("'")[1]
+    for subclass_key in parent.get_categories():
+        # Throws AttributeError (i.e. fails test) if subclass isn't defined in pycraigslist/api.py
+        eval(f"{parent_class_str}.{subclass_key}")
+    # Test passes if every suggested subclass of a parent class is valid
+    assert True
+
+
 @mark.parametrize("parent", specs.obj.pycraigslist_parents)
 def test_dtype_count(parent):
     """Tests attribute `count` returns int, i.e. the number of posts
